@@ -3,19 +3,21 @@ from __future__ import annotations
 from dataclasses import dataclass
 from typing import Any, Dict, Optional
 
+from .. import constants
 from .base import Method, Response
 
 
+class CoreBase:
+    method_namespace: Optional[str] = "Core"
+    using = set([constants.JMAP_URN_CORE])
+
+
+class EchoMethod:
+    method_type: Optional[str] = "echo"
+
+
 @dataclass
-class CoreEcho(Method):
-    @classmethod
-    def name(cls) -> str:
-        return "Core/echo"
-
-    @classmethod
-    def using(cls) -> set[str]:
-        return set()
-
+class CoreEcho(CoreBase, EchoMethod, Method):
     def to_dict(self, *args: Any, **kwargs: Any) -> Dict[str, Any]:
         return self.data or dict()
 
@@ -23,12 +25,9 @@ class CoreEcho(Method):
 
 
 @dataclass
-class CoreEchoResponse(Response):
+class CoreEchoResponse(CoreBase, EchoMethod, Response):
     data: Optional[Dict[str, Any]] = None
 
-    def to_dict(self, *args: Any, **kwargs: Any) -> Dict[str, Any]:
-        return self.data or dict()
-
     @classmethod
     def from_dict(
         cls, kvs: Any, *args: Any, **kwargs: Any
